﻿using System;
using System.Collections.ObjectModel;
using System.Configuration;
using CSWebSample;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WmsServerEdition;

namespace WmsPlugin
{
    public class WorldMapKitWmsLayerPlugin : WmsLayerPlugin
    {
        protected override MapConfiguration GetMapConfigurationCore(string style, string crs)
        {
            // Here you can configure your WorldMapKit data folder, get it from web.config or specify it directly
            string worldMapKitDataFolder = ConfigurationSettings.AppSettings["WorldMapKitDataFolder"];

            WorldMapKitRenderLayer worldMapKitRenderLayer = new WorldMapKitRenderLayer(worldMapKitDataFolder);

            MapConfiguration mapConfiguration = new MapConfiguration();
            mapConfiguration.Layers.Add(worldMapKitRenderLayer);

            return mapConfiguration;
        }

        // In this method you need to return the name of the Layer that WMS will expose.
        // You will use this name on the client to specify the layer you want to consume
        protected override string GetNameCore()
        {
            return "WorldMapKitLayer";
        }

        protected override Collection<string> GetProjectionsCore()
        {
            return new Collection<string> { "EPSG:4326" };
        }

        protected override RectangleShape GetBoundingBoxCore(string crs)
        {
            RectangleShape boundingBox = null;
            switch (crs)
            {
                case "EPSG:4326":
                    boundingBox = new RectangleShape(-180, 90, 180, -90);
                    break;
                case "EPSG:900913":
                    boundingBox = new RectangleShape(-20000000, 20000000, 20000000, -20000000);
                    break;
                default:
                    throw new ArgumentException("The input CRS is not supported by now, we only support EPSG:4326 and EPSG:900913.");
            }

            return boundingBox;
        }
    }
}
